@@ -3,11 +3,20 @@ import requests
 
 
 def get_available_languages():
+    langs = []
     from selenium import webdriver
     from selenium.webdriver.common.by import By
     import time
 
-    driver = webdriver.Safari()
+    driver = None
+
+    if sys.platform == "linux" or sys.platform == "linux2":
+        driver = webdriver.Firefox()
+    elif sys.platform == "darwin":
+        driver = webdriver.Safari()
+    elif sys.platform == "win32":
+        driver = webdriver.Firefox()
+
     driver.get("https://github.com/github/gitignore")
 
     # wait for the DOM to load
@@ -21,9 +30,11 @@ def get_available_languages():
         if i in [0, 1, 2, 3, 140]:
             pass
         else:
-            print(tr.text.split('.')[0])
+            langs.append(tr.text.split('.')[0])
         i += 1
 
+    return langs
+
 
 search = 'https://raw.githubusercontent.com/github/gitignore/main/'
 params = sys.argv[1:]
@@ -36,3 +47,4 @@ def generate_ignore(languages):
 
     with open('./.gitignore', 'w') as file:
         file.write(contents)
+
